@@ -1,9 +1,8 @@
-# -*- coding: utf-8 -*-
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2021 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2021 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2022 Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2011-2022 GNU Solidario <health@gnusolidario.org>
 #
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -21,23 +20,21 @@
 #
 ##############################################################################
 from trytond.model import ModelView, ModelSQL, fields
-from trytond.transaction import Transaction
 from trytond.rpc import RPC
-from trytond.pool import Pool
-from trytond.wizard import Wizard, StateAction, StateView, Button
-from trytond.pyson import Eval, Not, Bool, PYSONEncoder, Equal, And, Or
+from trytond.pyson import Eval, Not, Bool, Equal, Or
 import hashlib
 import json
 
-__all__ = ['HealthCrypto','PatientPrescriptionOrder',
-    'BirthCertificate','DeathCertificate','PatientEvaluation']
+
+__all__ = ['HealthCrypto', 'PatientPrescriptionOrder',
+           'BirthCertificate', 'DeathCertificate', 'PatientEvaluation']
 
 
 class HealthCrypto:
     """ GNU Health Cryptographic functions
     """
 
-    def serialize(self,data_to_serialize):
+    def serialize(self, data_to_serialize):
         """ Format to JSON """
         json_output = \
             json.dumps(data_to_serialize, ensure_ascii=False)
@@ -50,40 +47,40 @@ class HealthCrypto:
 class PatientPrescriptionOrder(ModelSQL, ModelView):
     """ Add the serialized and hash fields to the
     prescription order document"""
-    
+
     __name__ = 'gnuhealth.prescription.order'
-    
+
     serializer = fields.Text('Doc String', readonly=True)
 
     document_digest = fields.Char('Digest', readonly=True,
-        help="Original Document Digest")
+                                  help="Original Document Digest")
 
-    digest_status = fields.Function(fields.Boolean('Altered',
-        states={
-        'invisible': Not(Equal(Eval('state'),'done')),
-        },
-        help="This field will be set whenever parts of" \
-        " the main original document has been changed." \
-        " Please note that the verification is done only on selected" \
-        " fields." ),
+    digest_status = fields.Function(
+        fields.Boolean('Altered',
+                       states={
+                        'invisible': Not(Equal(Eval('state'), 'done')), },
+                       help="This field will be set whenever parts of"
+                            " the main original document has been changed."
+                            " Please note that the verification is done only "
+                            "on selected fields."),
         'check_digest')
 
-    serializer_current = fields.Function(fields.Text('Current Doc',
-            states={
-            'invisible': Not(Bool(Eval('digest_status'))),
-            }),
+    serializer_current = fields.Function(
+        fields.Text('Current Doc',
+                    states={
+                            'invisible': Not(Bool(Eval('digest_status'))),
+                            }),
         'check_digest')
 
-        
-    digest_current = fields.Function(fields.Char('Current Hash',
-            states={
-            'invisible': Not(Bool(Eval('digest_status'))),
-            }),
+    digest_current = fields.Function(
+        fields.Char('Current Hash',
+                    states={
+                     'invisible': Not(Bool(Eval('digest_status'))),
+                     }),
         'check_digest')
 
     digital_signature = fields.Text('Digital Signature', readonly=True)
 
-
     @staticmethod
     def default_state():
         return 'draft'
@@ -97,7 +94,7 @@ class PatientPrescriptionOrder(ModelSQL, ModelView):
             },
             'create_prescription': {
                 'invisible': Or(Equal(Eval('state'), 'done'),
-                    Equal(Eval('state'), 'validated'))
+                                Equal(Eval('state'), 'validated'))
             },
 
             })
@@ -112,31 +109,31 @@ class PatientPrescriptionOrder(ModelSQL, ModelView):
         prescription = prescriptions[0]
 
         # Change the state of the prescription to "Validated"
+        serial_doc = cls.get_serial(prescription)
 
-        serial_doc=cls.get_serial(prescription)
-        
         cls.write(prescriptions, {
             'serializer': serial_doc,
             'document_digest': HealthCrypto().gen_hash(serial_doc),
-            'state': 'validated',})
-
+            'state': 'validated', })
 
     @classmethod
-    def get_serial(cls,prescription):
+    def get_serial(cls, prescription):
+
+        presc_line = []
 
-        presc_line=[]
-        
         for line in prescription.prescription_line:
-            line_elements=[line.medicament and line.medicament.name.name or '',
-                line.dose or '', 
-                line.route and line.route.name or '',
-                line.form and line.form.name or '',
-                line.indication and line.indication.name or '',
-                line.short_comment or '']
-                
+            line_elements = [line.medicament and
+                             line.medicament.name.name or '',
+                             line.dose or '',
+                             line.dose_unit.name or '',
+                             line.route and line.route.name or '',
+                             line.form and line.form.name or '',
+                             line.indication and line.indication.name or '',
+                             line.short_comment or '']
+
             presc_line.append(line_elements)
 
-        data_to_serialize = { 
+        data_to_serialize = {
             'Prescription': str(prescription.prescription_id) or '',
             'Date': str(prescription.prescription_date) or '',
             'HP': str(prescription.healthprof.rec_name),
@@ -147,87 +144,86 @@ class PatientPrescriptionOrder(ModelSQL, ModelView):
              }
 
         serialized_doc = str(HealthCrypto().serialize(data_to_serialize))
-        
+
         return serialized_doc
-    
+
     @classmethod
     def set_signature(cls, data, signature):
         """
         Set the clearsigned signature
         """
-        
-            
+
         doc_id = data['id']
-        
+
         cls.write([cls(doc_id)], {
             'digital_signature': signature,
             })
 
-
-
-    def check_digest (self,name):
-        result=''
-        serial_doc=self.get_serial(self)
+    def check_digest(self, name):
+        result = ''
+        serial_doc = self.get_serial(self)
         if (name == 'digest_status' and self.document_digest):
             if (HealthCrypto().gen_hash(serial_doc) == self.document_digest):
                 result = False
             else:
                 ''' Return true if the document has been altered'''
                 result = True
-        if (name=='digest_current'):
+        if (name == 'digest_current'):
             result = HealthCrypto().gen_hash(serial_doc)
 
-        if (name=='serializer_current'):
+        if (name == 'serializer_current'):
             result = serial_doc
-            
+
         return result
- 
-    # Hide the group holding validation information when state is 
+
+    # Hide the group holding validation information when state is
     # not validated
-    
+
     @classmethod
     def view_attributes(cls):
         return [('//group[@id="prescription_digest"]', 'states', {
                 'invisible': Not(Eval('state') == 'validated'),
                 })]
-       
+
 
 class BirthCertificate(ModelSQL, ModelView):
-    
+
     __name__ = 'gnuhealth.birth_certificate'
-    
+
     serializer = fields.Text('Doc String', readonly=True)
 
     document_digest = fields.Char('Digest', readonly=True,
-        help="Original Document Digest")
-    
-    digest_status = fields.Function(fields.Boolean('Altered',
-        states={
-        'invisible': Not(Equal(Eval('state'),'done')),
-        },
-        help="This field will be set whenever parts of" \
-        " the main original document has been changed." \
-        " Please note that the verification is done only on selected" \
-        " fields." ),
+                                  help="Original Document Digest")
+
+    digest_status = fields.Function(
+        fields.Boolean('Altered',
+                       states={
+                        'invisible': Not(Equal(Eval('state'), 'done')),
+                       },
+                       help="This field will be set whenever parts of"
+                       " the main original document has been changed."
+                       " Please note that the verification is done only"
+                       " on selected "
+                       " fields."),
         'check_digest')
 
-    serializer_current = fields.Function(fields.Text('Current Doc',
-            states={
-            'invisible': Not(Bool(Eval('digest_status'))),
-            }),
+    serializer_current = fields.Function(
+        fields.Text('Current Doc',
+                    states={
+                            'invisible': Not(Bool(Eval('digest_status'))),
+                           }),
         'check_digest')
 
-        
-    digest_current = fields.Function(fields.Char('Current Hash',
-            states={
-            'invisible': Not(Bool(Eval('digest_status'))),
-            }),
+    digest_current = fields.Function(
+        fields.Char('Current Hash',
+                    states={
+                        'invisible': Not(Bool(Eval('digest_status'))),
+                    }),
         'check_digest')
 
     digital_signature = fields.Text('Digital Signature', readonly=True)
 
     @classmethod
-
     def __setup__(cls):
         super(BirthCertificate, cls).__setup__()
         cls._buttons.update({
@@ -243,114 +239,110 @@ class BirthCertificate(ModelSQL, ModelView):
     @ModelView.button
     def generate_birth_certificate(cls, certificates):
         certificate = certificates[0]
-        HealthProf = Pool().get('gnuhealth.healthprofessional')
 
         # Change the state of the certificate to "Done"
 
-        serial_doc=cls.get_serial(certificate)
-        
-        signing_hp = HealthProf.get_health_professional()
-        if not signing_hp:
-            cls.raise_user_error(
-                "No health professional associated to this user !")
+        serial_doc = cls.get_serial(certificate)
 
         cls.write(certificates, {
             'serializer': serial_doc,
             'document_digest': HealthCrypto().gen_hash(serial_doc),
-            'state': 'done',})
-
+            'state': 'done', })
 
     @classmethod
-    def get_serial(cls,certificate):
+    def get_serial(cls, certificate):
 
-        data_to_serialize = { 
+        data_to_serialize = {
             'certificate': str(certificate.code) or '',
             'Date': str(certificate.dob) or '',
-            'HP': certificate.signed_by \
-                and str(certificate.signed_by.rec_name) or '',
-            'Person':str(certificate.name.rec_name),
-            'Person_dob':str(certificate.name.dob) or '',
+            'HP': certificate.signed_by
+            and str(certificate.signed_by.rec_name) or '',
+            'Person': str(certificate.name.rec_name),
+            'Person_dob': str(certificate.name.dob) or '',
             'Person_ID': str(certificate.name.ref) or '',
             'Country': str(certificate.country.rec_name) or '',
-            'Country_subdivision': certificate.country_subdivision \
-                and str(certificate.country_subdivision.rec_name) or '',
-            'Mother': certificate.mother \
-                and str(certificate.mother.rec_name) or '',
-            'Father': certificate.father \
-                and str(certificate.father.rec_name) or '',
+            'Country_subdivision': certificate.country_subdivision
+            and str(certificate.country_subdivision.rec_name) or '',
+            'Mother': certificate.mother
+            and str(certificate.mother.rec_name) or '',
+            'Father': certificate.father
+            and str(certificate.father.rec_name) or '',
             'Observations': str(certificate.observations),
              }
 
         serialized_doc = str(HealthCrypto().serialize(data_to_serialize))
-        
+
         return serialized_doc
-    
+
     @classmethod
     def set_signature(cls, data, signature):
         """
         Set the clearsigned signature
         """
         doc_id = data['id']
-        
+
         cls.write([cls(doc_id)], {
             'digital_signature': signature,
             })
 
-    def check_digest (self,name):
-        result=''
-        serial_doc=self.get_serial(self)
+    def check_digest(self, name):
+        result = ''
+        serial_doc = self.get_serial(self)
         if (name == 'digest_status' and self.document_digest):
             if (HealthCrypto().gen_hash(serial_doc) == self.document_digest):
                 result = False
             else:
                 ''' Return true if the document has been altered'''
                 result = True
-        if (name=='digest_current'):
+        if (name == 'digest_current'):
             result = HealthCrypto().gen_hash(serial_doc)
 
-        if (name=='serializer_current'):
+        if (name == 'serializer_current'):
             result = serial_doc
-            
+
         return result
 
     # Hide the group holding all the digital signature until signed
-        
+
     @classmethod
     def view_attributes(cls):
         return [('//group[@id="group_current_string"]', 'states', {
                 'invisible': ~Eval('digest_status'),
                 })]
 
+
 class DeathCertificate(ModelSQL, ModelView):
-    
+
     __name__ = 'gnuhealth.death_certificate'
-    
+
     serializer = fields.Text('Doc String', readonly=True)
 
     document_digest = fields.Char('Digest', readonly=True,
-        help="Original Document Digest")
-    
-    digest_status = fields.Function(fields.Boolean('Altered',
-        states={
-        'invisible': Not(Equal(Eval('state'),'done')),
-        },
-        help="This field will be set whenever parts of" \
-        " the main original document has been changed." \
-        " Please note that the verification is done only on selected" \
-        " fields." ),
+                                  help="Original Document Digest")
+
+    digest_status = fields.Function(
+        fields.Boolean('Altered',
+                       states={
+                        'invisible': Not(Equal(Eval('state'), 'done')),
+                        },
+                       help="This field will be set whenever parts of"
+                       " the main original document has been changed."
+                       " Please note that the verification is done "
+                       " only on selected fields."),
         'check_digest')
 
-    serializer_current = fields.Function(fields.Text('Current Doc',
-            states={
-            'invisible': Not(Bool(Eval('digest_status'))),
-            }),
+    serializer_current = fields.Function(
+        fields.Text('Current Doc',
+                    states={
+                     'invisible': Not(Bool(Eval('digest_status'))),
+                    }),
         'check_digest')
 
-        
-    digest_current = fields.Function(fields.Char('Current Hash',
-            states={
-            'invisible': Not(Bool(Eval('digest_status'))),
-            }),
+    digest_current = fields.Function(
+        fields.Char('Current Hash',
+                    states={
+                     'invisible': Not(Bool(Eval('digest_status'))),
+                    }),
         'check_digest')
 
     digital_signature = fields.Text('Digital Signature', readonly=True)
@@ -372,124 +364,120 @@ class DeathCertificate(ModelSQL, ModelView):
     @ModelView.button
     def generate_death_certificate(cls, certificates):
         certificate = certificates[0]
-        HealthProf = Pool().get('gnuhealth.healthprofessional')
 
         # Change the state of the certificate to "Done"
 
-        serial_doc=cls.get_serial(certificate)
-        
-        signing_hp = HealthProf.get_health_professional()
-        if not signing_hp:
-            cls.raise_user_error(
-                "No health professional associated to this user !")
+        serial_doc = cls.get_serial(certificate)
 
         cls.write(certificates, {
             'serializer': serial_doc,
             'document_digest': HealthCrypto().gen_hash(serial_doc),
-            'state': 'done',})
-
+            'state': 'done', })
 
     @classmethod
-    def get_serial(cls,certificate):
+    def get_serial(cls, certificate):
+
+        underlying_conds = []
 
-        underlying_conds =[]
-        
         for condition in certificate.underlying_conditions:
             cond = []
             cond = [str(condition.condition.rec_name),
-                condition.interval,
-                condition.unit_of_time]
-                
+                    condition.interval,
+                    condition.unit_of_time]
+
             underlying_conds.append(cond)
 
-        data_to_serialize = { 
+        data_to_serialize = {
             'certificate': str(certificate.code) or '',
             'Date': str(certificate.dod) or '',
-            'HP': certificate.signed_by \
-                and str(certificate.signed_by.rec_name) or '',
+            'HP': certificate.signed_by
+            and str(certificate.signed_by.rec_name) or '',
             'Person': str(certificate.name.rec_name),
-            'Person_dob':str(certificate.name.dob) or '',
+            'Person_dob': str(certificate.name.dob) or '',
             'Person_ID': str(certificate.name.ref) or '',
             'Cod': str(certificate.cod.rec_name),
-            'Underlying_conditions': underlying_conds or '',    
+            'Underlying_conditions': underlying_conds or '',
             'Autopsy': certificate.autopsy,
             'Type_of_death': str(certificate.type_of_death),
             'Place_of_death': str(certificate.place_of_death),
             'Country': str(certificate.country.rec_name) or '',
-            'Country_subdivision': certificate.country_subdivision \
-                and str(certificate.country_subdivision.rec_name) or '',
+            'Country_subdivision': certificate.country_subdivision
+            and str(certificate.country_subdivision.rec_name) or '',
             'Observations': str(certificate.observations),
              }
 
         serialized_doc = str(HealthCrypto().serialize(data_to_serialize))
-        
+
         return serialized_doc
-    
+
     @classmethod
     def set_signature(cls, data, signature):
         """
         Set the clearsigned signature
         """
         doc_id = data['id']
-        
+
         cls.write([cls(doc_id)], {
             'digital_signature': signature,
             })
 
-    def check_digest (self,name):
-        result=''
-        serial_doc=self.get_serial(self)
+    def check_digest(self, name):
+        result = ''
+        serial_doc = self.get_serial(self)
         if (name == 'digest_status' and self.document_digest):
             if (HealthCrypto().gen_hash(serial_doc) == self.document_digest):
                 result = False
             else:
                 ''' Return true if the document has been altered'''
                 result = True
-        if (name=='digest_current'):
+        if (name == 'digest_current'):
             result = HealthCrypto().gen_hash(serial_doc)
 
-        if (name=='serializer_current'):
+        if (name == 'serializer_current'):
             result = serial_doc
-            
+
         return result
 
     # Hide the group holding all the digital signature until signed
-        
+
     @classmethod
     def view_attributes(cls):
         return [('//group[@id="group_current_string"]', 'states', {
                 'invisible': ~Eval('digest_status'),
                 })]
 
+
 class PatientEvaluation(ModelSQL, ModelView):
     __name__ = 'gnuhealth.patient.evaluation'
-    
+
     serializer = fields.Text('Doc String', readonly=True)
 
     document_digest = fields.Char('Digest', readonly=True,
-        help="Original Document Digest")
-    
-    digest_status = fields.Function(fields.Boolean('Altered',
-        states={
-        'invisible': Not(Equal(Eval('state'),'signed')),
-        },
-        help="This field will be set whenever parts of" \
-        " the main original document has been changed." \
-        " Please note that the verification is done only on selected" \
-        " fields." ),
+                                  help="Original Document Digest")
+
+    digest_status = fields.Function(
+        fields.Boolean('Altered',
+                       states={
+                        'invisible': Not(Equal(Eval('state'), 'signed')),
+                        },
+                       help="This field will be set whenever parts of"
+                            " the main original document has been changed."
+                            " Please note that the verification is done"
+                            " only on selected fields."),
         'check_digest')
 
-    serializer_current = fields.Function(fields.Text('Current Doc',
-            states={
-            'invisible': Not(Bool(Eval('digest_status'))),
-            }),
+    serializer_current = fields.Function(
+        fields.Text('Current Doc',
+                    states={
+                            'invisible': Not(Bool(Eval('digest_status'))),
+                            }),
         'check_digest')
 
-        
-    digest_current = fields.Function(fields.Char('Current Hash',
-            states={
-            'invisible': Not(Bool(Eval('digest_status'))),
-            }),
+    digest_current = fields.Function(
+        fields.Char('Current Hash',
+                    states={
+                            'invisible': Not(Bool(Eval('digest_status'))),
+                            }),
         'check_digest')
 
     digital_signature = fields.Text('Digital Signature', readonly=True)
@@ -507,76 +495,63 @@ class PatientEvaluation(ModelSQL, ModelView):
                 'set_signature': RPC(readonly=False),
                 })
 
-
     @classmethod
     @ModelView.button
     def sign_evaluation(cls, evaluations):
         evaluation = evaluations[0]
 
-        HealthProf= Pool().get('gnuhealth.healthprofessional')
-        
         # Change the state of the evaluation to "Signed"
-        # Include signing health professional 
-        
-        serial_doc=cls.get_serial(evaluation)
-
-
-        signing_hp = HealthProf.get_health_professional()
-        if not signing_hp:
-            cls.raise_user_error(
-                "No health professional associated to this user !")
-
 
+        serial_doc = cls.get_serial(evaluation)
 
         cls.write(evaluations, {
             'serializer': serial_doc,
             'document_digest': HealthCrypto().gen_hash(serial_doc),
-            'state': 'signed',})
-
+            'state': 'signed', })
 
     @classmethod
-    def get_serial(cls,evaluation):
+    def get_serial(cls, evaluation):
+
+        signs_symptoms = []
+        secondary_conditions = []
+        diagnostic_hypotheses = []
+        procedures = []
 
-        signs_symptoms =[]
-        secondary_conditions =[]
-        diagnostic_hypotheses =[]
-        procedures =[]
-        
         for sign_symptom in evaluation.signs_and_symptoms:
             finding = []
             finding = [sign_symptom.clinical.rec_name,
-                sign_symptom.sign_or_symptom,
-                ]
-                
+                       sign_symptom.sign_or_symptom,
+                       ]
+
             signs_symptoms.append(finding)
 
         for secondary_condition in evaluation.secondary_conditions:
             sc = []
             sc = [secondary_condition.pathology.rec_name]
-                
+
             secondary_conditions.append(sc)
 
         for ddx in evaluation.diagnostic_hypothesis:
             dx = []
             dx = [ddx.pathology.rec_name]
-                
+
             diagnostic_hypotheses.append(dx)
 
         for procedure in evaluation.actions:
             proc = []
             proc = [procedure.procedure.rec_name]
-                
+
             procedures.append(proc)
 
-        data_to_serialize = { 
+        data_to_serialize = {
             'Patient': str(evaluation.patient.rec_name) or '',
             'Start': str(evaluation.evaluation_start) or '',
             'End': str(evaluation.evaluation_endtime) or '',
             'Initiated_by': str(evaluation.healthprof.rec_name),
             'Signed_by': evaluation.signed_by and
-                str(evaluation.signed_by.rec_name) or '',
+            str(evaluation.signed_by.rec_name) or '',
             'Specialty': evaluation.specialty and
-                str(evaluation.specialty.rec_name) or '',
+            str(evaluation.specialty.rec_name) or '',
             'Visit_type': str(evaluation.visit_type) or '',
             'Urgency': str(evaluation.urgency) or '',
             'Information_source': str(evaluation.information_source) or '',
@@ -596,7 +571,6 @@ class PatientEvaluation(ModelSQL, ModelView):
             'BPM': evaluation.bpm or '',
             'Respiratory_rate': evaluation.respiratory_rate or '',
             'Osat': evaluation.osat or '',
-            'BPM': evaluation.bpm or '',
             'Malnutrition': evaluation.malnutrition,
             'Dehydration': evaluation.dehydration,
             'Temperature': evaluation.temperature,
@@ -607,7 +581,6 @@ class PatientEvaluation(ModelSQL, ModelView):
             'Abdominal_cir': evaluation.abdominal_circ or '',
             'Hip': evaluation.hip or '',
             'WHR': evaluation.whr or '',
-            'Abdominal_cir': evaluation.abdominal_circ or '',
             'Loc': evaluation.loc or '',
             'Loc_eyes': evaluation.loc_eyes or '',
             'Loc_verbal': evaluation.loc_verbal or '',
@@ -615,68 +588,67 @@ class PatientEvaluation(ModelSQL, ModelView):
             'Tremor': evaluation.tremor,
             'Violent': evaluation.violent,
             'Mood': str(evaluation.mood) or '',
-            'Orientation':evaluation.orientation,
-            'Orientation':evaluation.orientation,
-            'Memory':evaluation.memory,
-            'Knowledge_current_events':evaluation.knowledge_current_events,
-            'Judgment':evaluation.judgment,
-            'Abstraction':evaluation.abstraction,
-            'Vocabulary':evaluation.vocabulary,
-            'Calculation':evaluation.calculation_ability,
-            'Object_recognition':evaluation.object_recognition,
-            'Praxis':evaluation.praxis,
-            'Diagnosis':evaluation.diagnosis and
-                str(evaluation.diagnosis.rec_name) or '',
+            'Orientation': evaluation.orientation,
+            'Memory': evaluation.memory,
+            'Knowledge_current_events': evaluation.knowledge_current_events,
+            'Judgment': evaluation.judgment,
+            'Abstraction': evaluation.abstraction,
+            'Vocabulary': evaluation.vocabulary,
+            'Calculation': evaluation.calculation_ability,
+            'Object_recognition': evaluation.object_recognition,
+            'Praxis': evaluation.praxis,
+            'Diagnosis': evaluation.diagnosis and
+            str(evaluation.diagnosis.rec_name) or '',
             'Secondary_conditions': secondary_conditions or '',
             'DDX': diagnostic_hypotheses or '',
-            'Info_Diagnosis':str(evaluation.info_diagnosis) or '',
-            'Treatment_plan':str(evaluation.directions) or '',
+            'Info_Diagnosis': str(evaluation.info_diagnosis) or '',
+            'Treatment_plan': str(evaluation.directions) or '',
             'Procedures': procedures or '',
             'Institution': evaluation.institution and
-                str(evaluation.institution.rec_name) or '',
+            str(evaluation.institution.rec_name) or '',
             'Derived_from': evaluation.derived_from and
-                str(evaluation.derived_from.rec_name) or '',
-            'Derived_to':evaluation.derived_to and
-                str(evaluation.derived_to.rec_name) or '',
+            str(evaluation.derived_from.rec_name) or '',
+            'Derived_to': evaluation.derived_to and
+            str(evaluation.derived_to.rec_name) or '',
              }
 
         serialized_doc = str(HealthCrypto().serialize(data_to_serialize))
-        
+
         return serialized_doc
-    
+
     @classmethod
     def set_signature(cls, data, signature):
         """
         Set the clearsigned signature
         """
         doc_id = data['id']
-        
+
         cls.write([cls(doc_id)], {
             'digital_signature': signature,
             })
 
-    def check_digest (self,name):
-        result=''
-        serial_doc=str(self.get_serial(self))
+    def check_digest(self, name):
+        result = ''
+        serial_doc = str(self.get_serial(self))
         if (name == 'digest_status' and self.document_digest):
             if (HealthCrypto().gen_hash(serial_doc) == self.document_digest):
                 result = False
             else:
                 ''' Return true if the document has been altered'''
                 result = True
-        if (name=='digest_current'):
+        if (name == 'digest_current'):
             result = HealthCrypto().gen_hash(serial_doc)
 
-        if (name=='serializer_current'):
+        if (name == 'serializer_current'):
             result = serial_doc
-            
+
         return result
     # Hide the group holding all the digital signature until signed
-        
+
     @classmethod
     def view_attributes(cls):
         return [('//group[@id="group_digital_signature"]', 'states', {
                 'invisible': ~Eval('digital_signature')}),
                 ('//group[@id="group_current_string"]', 'states', {
-                'invisible': ~Eval('digest_status'),
-                })]
+                 'invisible': ~Eval('digest_status'),
+                 })]
