@@ -2,8 +2,8 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2021 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2021 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2022 Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2011-2022 GNU Solidario <health@gnusolidario.org>
 #
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -22,13 +22,13 @@
 ##############################################################################
 
 from trytond.pool import Pool
-from .health_qrcodes import *
+from .import health_qrcodes
 
 
 def register():
     Pool.register(
-        Patient,
-        Appointment,
-        Newborn,
-        LabTest,
+        health_qrcodes.Patient,
+        health_qrcodes.Appointment,
+        health_qrcodes.Newborn,
+        health_qrcodes.LabTest,
         module='health_qrcodes', type_='model')
